@@ -138,7 +138,7 @@ class TestIntegration(base.BaseTestCase):
         if self.short_name == 'nova':
             found = False
             for _, _, filenames in os.walk(root):
-                if 'migrate.cfg' in filenames:
+                if 'alembic.ini' in filenames:
                     found = True
             self.assertTrue(found)
         venv = self.useFixture(
@@ -210,20 +210,24 @@ class TestMarkersPip(base.BaseTestCase):
 
     scenarios = [
         ('pip-latest', {'modules': ['pip']}),
-        ('setuptools-Bionic', {
-            'modules': ['pip==9.0.1', 'setuptools==39.0.1']}),
-        ('setuptools-Stretch', {
-            'modules': ['pip==9.0.1', 'setuptools==33.1.1']}),
-        ('setuptools-EL8', {'modules': ['pip==9.0.3', 'setuptools==39.2.0']}),
-        ('setuptools-Buster', {
-            'modules': ['pip==18.1', 'setuptools==40.8.0']}),
-        ('setuptools-Focal', {
-            'modules': ['pip==20.0.2', 'setuptools==45.2.0']}),
+        (
+            'setuptools-Bullseye',
+            {'modules': ['pip==20.3.4', 'setuptools==52.0.0']},
+        ),
+        (
+            'setuptools-Focal',
+            {'modules': ['pip==20.0.2', 'setuptools==45.2.0']},
+        ),
+        (
+            'setuptools-Jammy',
+            {'modules': ['pip==22.0.2', 'setuptools==59.6.0']},
+        ),
     ]
 
     @testtools.skipUnless(
         os.environ.get('PBR_INTEGRATION', None) == '1',
-        'integration tests not enabled')
+        'integration tests not enabled',
+    )
     def test_pip_versions(self):
         pkgs = {
             'test_markers':
@@ -260,21 +264,33 @@ class TestMarkersPip(base.BaseTestCase):
             allow_fail=False)[0])
 
 
-class TestLTSSupport(base.BaseTestCase):
-
-    # These versions come from the versions installed from the 'virtualenv'
-    # command from the 'python-virtualenv' package.
-    scenarios = [
+# Handle collections.abc moves in python breaking old pip
+# These versions come from the versions installed from the 'virtualenv'
+# command from the 'python-virtualenv' package.
+if sys.version_info[0:3] < (3, 10, 0):
+    lts_scenarios = [
         ('Bionic', {'modules': ['pip==9.0.1', 'setuptools==39.0.1']}),
         ('Stretch', {'modules': ['pip==9.0.1', 'setuptools==33.1.1']}),
         ('EL8', {'modules': ['pip==9.0.3', 'setuptools==39.2.0']}),
         ('Buster', {'modules': ['pip==18.1', 'setuptools==40.8.0']}),
         ('Focal', {'modules': ['pip==20.0.2', 'setuptools==45.2.0']}),
     ]
+else:
+    lts_scenarios = [
+        ('Bullseye', {'modules': ['pip==20.3.4', 'setuptools==52.0.0']}),
+        ('Focal', {'modules': ['pip==20.0.2', 'setuptools==45.2.0']}),
+        ('Jammy', {'modules': ['pip==22.0.2', 'setuptools==59.6.0']}),
+    ]
+
+
+class TestLTSSupport(base.BaseTestCase):
+
+    scenarios = lts_scenarios
 
     @testtools.skipUnless(
         os.environ.get('PBR_INTEGRATION', None) == '1',
-        'integration tests not enabled')
+        'integration tests not enabled',
+    )
     def test_lts_venv_default_versions(self):
         venv = self.useFixture(
             test_packaging.Venv('setuptools', modules=self.modules))
